DMTPY - Python runtime library for DMT based models
=================================================================

Serves as a common base for libraries that are generated by the SINTEF DMT Python code generator

## Authors

* **Lasse Bjermeland** - [lassebje](https://github.com/lassebje)

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.